declare module "result" {
    import { Maybe } from "maybe";
    export type Result<O, E> = {
        ap: <A>(r: Result<A, E>) => Result<A, E>;
        map: <A>(cb: (arg?: O) => A) => Result<A, E>;
        mapErr: <A>(cb: (arg?: E) => A) => Result<O, A>;
        chain: <A>(cb: (arg?: O) => Result<A, E>) => Result<A, E>;
        chainErr: <A>(cb: (arg?: E) => Result<O, A>) => Result<O, A>;
        swap: () => Result<O, E>;
        bimap: <A, B>(ok: (arg?: O) => A, err: (arg?: E) => B) => Result<A, B>;
        cata: <A, B>(obj: {
            Ok: (arg?: O) => A;
            Err: (arg?: E) => B;
        }) => A | B;
        toMaybe: () => Maybe<O>;
        inspect: () => string;
        isErr: () => boolean;
        isOk: () => boolean;
    };
    export const Ok: <O>(arg?: O) => Result<O, any>;
    export const Err: <E>(arg?: E) => Result<any, E>;
}
declare module "maybe" {
    import { Result } from "result";
    export type Maybe<A> = {
        ap: <B>(m: Maybe<any>) => Maybe<B>;
        map: <B>(cb: (arg: A) => B) => Maybe<B>;
        chain: <B>(cb: (arg: A) => Maybe<B>) => Maybe<B>;
        alt: <B>(value: B) => Maybe<A | B>;
        cata: <B, C>(obj: {
            Just: (arg: A) => B;
            Nothing: () => C;
        }) => B | C;
        toResult: () => Result<any, any>;
        inspect: () => string;
        isNothing: () => boolean;
        isJust: () => boolean;
    };
    export const Just: <A>(arg: A) => Maybe<A>;
    export const Nothing: Maybe<any>;
    export const nullable: <T>(arg?: T) => Maybe<NonNullable<T>>;
}
declare module "encase" {
    import { Maybe } from "maybe";
    import { Result } from "result";
    export const encase: <A>(func: () => A) => Maybe<A>;
    export const encaseRes: <A, E>(func: () => A) => Result<A, E>;
}
declare module "get" {
    import { Maybe } from "maybe";
    export const get: <A>(selector: (string | number)[]) => (data: any) => Maybe<A>;
}
declare module "head" {
    import { Maybe } from "maybe";
    export const head: <A>(arr: A[]) => Maybe<A>;
}
declare module "justs" {
    import { Maybe } from "maybe";
    export const justs: <A>(arr?: Maybe<A>[]) => Maybe<A>[];
}
declare module "last" {
    import { Maybe } from "maybe";
    export const last: <A>(arr: A[]) => Maybe<A>;
}
declare module "oks" {
    import { Result } from "result";
    export const oks: <A>(arr?: Result<A, any>[]) => Result<A, any>[];
}
declare module "parseDate" {
    import { Maybe } from "maybe";
    export const parseDate: (date: any) => Maybe<Date>;
}
declare module "tail" {
    import { Maybe } from "maybe";
    export const tail: <A>(arr: A[]) => Maybe<A>;
}
declare module "tryFind" {
    import { Maybe } from "maybe";
    export const tryFind: <A>(exp: (a: A) => boolean) => (data: A[]) => Maybe<A>;
}
